;**************************************************************************
;	Example1.PRG	
;	Example program for a simple reciprocating move
;	ASSUMES drive is already configured and servo-loop tuned
;	Version 1.0                            
;	Parker Hannifin PLC             
;	Electromechanical Division 
;
;	Date:	17/05/02
;
;**************************************************************************
; Programming notes: -
; 1) All commands must be preceeded by an axis address number e.g. 1ON
; 2) Spaces are not allowed within any command e.g. 2GOSUB ( FRED ) is
;    a syntax error.
; 3) A semi-colon (;) defines the start of a comment.
; 4) Comments are not stored in the indexer.
; 5) You must CLEAR all sequence labels before defining new ones.
; 6) You must DECLARE user defined labels in START before using them.
; 7) You must define a PROFILE before USEing it. 
;**************************************************************************

1S                    	;Stop any program that is running
1CLEAR(ALL)		;Erase all program labels and declarations

;Initialisation code
1START:			;This label is pre-defined    
   1DECLARE(TEST) 	;Declare user defined labels used in program here

   1ON			;Energise the axis
   1LIMITS(3,1,0,200)	;Disable end of travel limits

   1MI 	          	;Mode is incremental indexing
   1O(000)		;Reset all outputs

   1V1			;Set velocity in rps
   1AA50      		;Set acceleration rate in rps/s
   1AD10		;Set deceleration rate in rps/s
   1D4000		;Set distance to index

   1LOOP(TEST,10) 	;Do TEST label 10 times
1END             	;End of START sequence

1TEST:			;Define TEST label sequence
   1O(1)		;Turn on output 1 - we're busy!
   1G			;Execute move
   1O(0)		;Turn off output 1
   1T1			;Wait a while
   1H			;Toggle the direction ready for next move
1END			;End of label sequence definition

;Now type in the following command in the TERMINAL window to run START label
;1GOTO(START)		;After downloading run the START label

;********** End of program file ********************************************
