;**************************************************************************
;	Example2.PRG	
;	Example program for repeating moves with PDFX or DIN Rail L/H drive
;	ASSUMES drive is already configured and servo-loop tuned
;	Version 1.0                            
;	Parker Hannifin PLC             
;	Electromechanical Division 
;
;	Date:	17/05/02
;
;**************************************************************************
; Programming notes: -
; 1) All commands must be preceeded by an axis address number e.g. 1ON
; 2) Spaces are not allowed within any command e.g. 2GOSUB ( FRED ) is
;    a syntax error.
; 3) A semi-colon (;) defines the start of a comment.
; 4) Comments are not stored in the indexer.
; 5) You must CLEAR all sequence labels before defining new ones.
; 6) You must DECLARE user defined labels in START before using them.
; 7) You must define a PROFILE before USEing it. 
;**************************************************************************

1S                    	;Stop any program that is running
1CLEAR(ALL)		;Erase all program labels and declarations

;Auto run initialisation code
1START:			;This label is pre-defined    
   1DECLARE(DATUM)	;Declare user defined labels used in program here
   1DECLARE(MOVE1)	;MUST declare before defining routines
   1DECLARE(MOVE2)
   1DECLARE(MOVE3)       

   ;Setup some move profiles
   ;Format is Profile no.(AA,AD,D,V)
   1PROFILE1(50,50,4000,3)                  
   1PROFILE2(150,150,20000,8)

   1ON			;Energise the axis
   1LIMITS(0,1,0,500)	;Enable normally closed, end of travel limits

   1MI 	          	;Mode incremental indexing
   1O(000)		;Reset all outputs

   1GOSUB(DATUM)	;Go home to datum
   1T1.0 		;Wait a while

   1USE(1)		;Use profile 1
   1LOOP(MOVE1,5)	;Do MOVE1 5 times

   1USE(2)		;Use profile 2
   1LOOP(MOVE2,5)	;Do MOVE2 5 times

   1D40000		;Distance 40 revs
   1V7.5		;Velocity of move in rps
   1A250		;Acceleration of move in rps/s
   1LOOP(MOVE3,5)	;Do MOVE3 5 times
1END             	;End of START sequence

;Homing routine
1DATUM:  	        ;Homing subroutine
   ;Stop on +ve side of normally open switch,
   ;+ direction at 2 rps, acceleration = 50 rps/s, 
   1HOME1(+,1,+2,50,0)	
   1TR(IN,=,1XXXX)	;Wait for start input (number 1)
   1O(1)		;Set "moving" output
   1GH              	;Execute homing move
   1O(0)		;Reset "moving" output

   1TR(IN,=,1XXXX)	;Wait for start input (number 1)
   1D-12000		;Offset to start position
   1V2			;Velocity
   1A50			;Acceleration
   1O(1)                ;Set "moving" output
   1G			;Move to start position
   1W(PT,0)             ;Zero the controller position counter
   1O(0)		;Reset "moving" output
1END   	        	;End of subroutine

;Move 1 routine
1MOVE1:			;Define label
   1TR(IN,=,1XXXX)	;Wait for start input (number 1)
   1O(1)		;Set output 1
   1G			;Do the move
   1T0.2		;Wait a while
   1H			;Reverse direction
   1O(0)		;Reset output 1
1END			;End of subroutine

;Move 2 routine
1MOVE2:			;Define label
   1TR(IN,=,1XXXX)	;Wait for start input (number 1)
   1O(01)		;Set output 2
   1G			;Do the move
   1T0.5		;Wait a while
   1H			;Reverse direction
   1O(X0)		;Reset output 2
1END			;End of subroutine

;Move 3 routine
1MOVE3:			;Define label
   1TR(IN,=,1XXXX)	;Wait for start input (number 1)
   1O(XX1)		;Set output 3
   1G			;Do move
   1T1			;Wait a while
   1H			;Reverse direction
   1O(XX0)		;Reset output 3
1END			;End of subroutine

1ARM11			;Enable auto-run on power up
1SV  		     	;Save all the above

;********** End of program file **********************************************
